@@ -527,7 +527,7 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
       draw->PopForeground();
     }
     else {
-      for (size_t j=0; j<=8; j++) {
+      for (size_t j=0; j<Sudoku::dimension; j++) {
         if (marks[i] & (1 << j)) {
           std::wstring         text(Lum::Base::NumberToWString(j+1));
           Lum::OS::FontExtent  extent;
@@ -783,6 +783,24 @@ void GameArea::SetFocusedCellValue(size_t value)
   SetFinished(game==solution);
 }
 
+void GameArea::MarkEmpty()
+{
+  assert(!finished->Get());
+
+  for (size_t cell=0; cell<Sudoku::dimension*Sudoku::dimension; cell++) {
+    if (riddle.Get(cell)==Sudoku::empty &&
+        game.Get(cell)==Sudoku::empty &&
+        marks[cell]==0) {
+      marks[cell]=0;
+      for (size_t mark=0; mark<Sudoku::dimension; mark++) {
+        marks[cell]|=(1 << mark);
+      }
+    }
+  }
+
+  Redraw();
+}
+
 void GameArea::Solve()
 {
   SetFinished(true);
