@@ -130,6 +130,7 @@ class MainDialog : public Lum::Dialog
 private:
   Lum::Model::ActionRef         clearAction;
   Lum::Model::ActionRef         generateAction;
+  Lum::Model::ActionRef         markEmptyAction;
   Lum::Model::ActionRef         solveAction;
   Lum::Model::ActionRef         statAction;
   Lum::Model::ActionRef         helpAction;
@@ -148,6 +149,7 @@ public:
   MainDialog()
   : clearAction(new Lum::Model::Action),
     generateAction(new Lum::Model::Action),
+    markEmptyAction(new Lum::Model::Action),
     solveAction(new Lum::Model::Action),
     statAction(new Lum::Model::Action),
     helpAction(new Lum::Model::Action),
@@ -172,6 +174,7 @@ public:
 
     Observe(clearAction);
     Observe(generateAction);
+    Observe(markEmptyAction);
     Observe(solveAction);
     Observe(statAction);
     Observe(helpAction);
@@ -184,6 +187,7 @@ public:
     Observe(gameArea->GetFocusChangedAction());
     Observe(gameArea->GetFinishedModel());
 
+    Lum::Images::loader->SetNormalImagePostfix(L"");
     Lum::Images::loader->LoadApplication(L"Hint.png",hintImage);
     Lum::Images::loader->LoadApplication(L"Statistics.png",statisticsImage);
     Lum::Images::loader->LoadApplication(L"Solve.png",solveImage);
@@ -249,8 +253,9 @@ public:
       array->Add(toggle);
     }
     else {
-      array->Add(Lum::Toggle::Create(_(L"GAME_Hint",L"Hint"),gameArea->GetHintMode(),true,false));
+      array->Add(Lum::Toggle::Create(_(L"GAME_HINT",L"Hint"),gameArea->GetHintMode(),true,false));
     }
+
     if (statisticsImage->IsValid()) {
       array->Add(Lum::Button::Create(Lum::Image::Create(statisticsImage),statAction,true,false));
     }
@@ -289,6 +294,9 @@ public:
                                   .SetShortcut(Lum::OS::qualifierControl,L"g"),
                                   generateAction)
                  .SetOpensDialog())
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_MARK_EMPTY",L"_Mark empty"))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"m"),
+                                  markEmptyAction))
         ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_SOLVE",L"_Solve game"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"s"),
                                   solveAction))
@@ -486,6 +494,7 @@ public:
       }
 
       if (gameArea->GetFinishedModel()->Get()) {
+        markEmptyAction->Disable();
         solveAction->Disable();
         statAction->Disable();
       }
@@ -512,6 +521,7 @@ public:
     }
     else if (model==generateTask.GetFinishedAction() &&
              generateTask.GetFinishedAction()->IsFinished()) {
+      markEmptyAction->Enable();
       solveAction->Enable();
       statAction->Enable();
       SetRiddle();
@@ -521,6 +531,10 @@ public:
              generateTask.GetAbortedAction()->IsFinished()) {
       gameArea->GetFinishedModel()->On(false);
     }
+    else if (model==markEmptyAction &&
+             markEmptyAction->IsFinished()) {
+      gameArea->MarkEmpty();
+    }
     else if (model==solveAction &&
              solveAction->IsFinished() &&
              solveAction->IsEnabled()) {
@@ -534,6 +548,7 @@ public:
         gameArea->GetFinishedModel()->Off();
         gameArea->Solve();
         gameArea->GetFinishedModel()->On(false);
+        markEmptyAction->Disable();
         solveAction->Disable();
         statAction->Disable();
       }
@@ -578,6 +593,7 @@ public:
                               L"It looks like you have successfully finished\n"
                               L"the given puzzle!\n"
                               L"Congratulations!"));
+      markEmptyAction->Disable();
       solveAction->Disable();
       statAction->Disable();
       UpdateKeypad();
